# pyNNMF - Non-Negative Matrix Factorization (NNMF)

Library for computing Non-Negative Matrix Factorisation with missing values imputation.

## Authors

* **Mário Antunes** - [mariolpantunes](https://github.com/mariolpantunes)

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details

## Status

![Python CI](https://github.com/mariolpantunes/pyNNMF/workflows/Python%20CI/badge.svg)
